@@ -2,6 +2,7 @@ import io
 import os
 import re
 import zipfile
+import pathlib
 
 from slurmqueen.slurm_script import base_script
 from slurmqueen.experiment import Experiment, ExperimentInstance
@@ -46,9 +47,8 @@ class SlurmExperiment(Experiment):
     def __init__(
         self,
         exp_id,
-        command,
-        args,
-        dependencies,
+        *commands,
+        dependencies=None,
         setup_commands=None,
         output_argument=">>",
         log_argument="2>",
@@ -57,16 +57,19 @@ class SlurmExperiment(Experiment):
         Initialize an experiment.
 
         :param exp_id: string name of the experiment instance (e.g. 'alpha1')
-        :param command: the command to run in each task, relative to experiment folder (e.g. 'python cnfxor.py')
-        :param args: a list of dictionaries; each dictionary defines a new task
-        :param dependencies: a list of files required to run the tool, relative to experiment folder (e.g. 'cnfxor.py')
+        :param commands: the Commands to run in each task, relative to experiment folder (e.g. 'python cnfxor.py')
+        :param dependencies: a list of files/globs required to run the tool, relative to experiment folder (e.g. 'cnfxor.py')
         :param setup_commands: The setup to perform on each worker node before beginning tasks
         :param output_argument: the argument used to pass the name of the .out file (defaults to stdout)
         :param log_argument: the argument used to pass the name of the .log file (defaults to stderr)
         """
-        super().__init__(command, args, output_argument, log_argument)
+        super().__init__(
+            *commands, output_argument=output_argument, log_argument=log_argument
+        )
 
         self.id = exp_id
+        if dependencies is None:
+            dependencies = []
         self.dependencies = dependencies
         self.setup_commands = setup_commands
 
@@ -90,19 +93,20 @@ class SlurmExperiment(Experiment):
         :param max_size: The maximum number of tasks to include on each experiment.
         :return: A list of experiments, containing in total the same tasks of this experiment.
         """
-        num_partitions = int((max_size - 1 + len(self.args)) / max_size)
-        size = int((num_partitions - 1 + len(self.args)) / num_partitions)
+        num_partitions = int((max_size - 1 + len(self.commands)) / max_size)
+        size = int((num_partitions - 1 + len(self.commands)) / num_partitions)
 
         res = []
         for i in range(num_partitions):
-            args_subset = self.args[(i * size) : (i * size + size)]
+            args_subset = self.commands[(i * size) : (i * size + size)]
             res.append(
                 SlurmExperiment(
                     self.id + "/" + str(i),
-                    self.command,
-                    self.dependencies,
                     args_subset,
+                    dependencies=self.dependencies,
                     setup_commands=self.setup_commands,
+                    output_argument=self.output_argument,
+                    log_argument=self.log_argument,
                 )
             )
         return res
@@ -221,10 +225,10 @@ class SlurmInstance(ExperimentInstance):
             return False
         output_files = self.output_filenames()
         if len(output_files) > 0:
-            if len(output_files) < len(self._exp.args) and verbose:
+            if len(output_files) < len(self._exp.commands) and verbose:
                 print(
                     "Finished. Only %d/%d output files."
-                    % (len(output_files), len(self._exp.args))
+                    % (len(output_files), len(self._exp.commands))
                 )
             return True
         return False
@@ -264,7 +268,7 @@ class SlurmInstance(ExperimentInstance):
                 return
 
             output_files = self.output_filenames()
-            if len(output_files) == len(self._exp.args):
+            if len(output_files) == len(self._exp.commands):
                 status_label.value = "Finished."
                 run_button.disabled = True
                 complete_button.disabled = True
@@ -272,7 +276,7 @@ class SlurmInstance(ExperimentInstance):
             elif len(output_files) > 0:
                 status_label.value = "Finished. Only %d/%d output files" % (
                     len(output_files),
-                    len(self._exp.args),
+                    len(self._exp.commands),
                 )
                 run_button.disabled = True
                 complete_button.disabled = True
@@ -400,18 +404,28 @@ class SlurmInstance(ExperimentInstance):
         :return: None
         """
         with self._config.server.ftp_connect() as ftp:
-            for filename in files:
-                # If the dependency belongs in a separate folder, make it
-                if "/" in filename:
-                    self._config.server.execute(
-                        "mkdir -p "
-                        + self.remote_experiment_path(filename[: filename.rfind("/")])
-                    )
 
-                ftp.put(
-                    self.local_project_path(filename),
-                    self.remote_experiment_path(filename),
-                )
+            project_path = pathlib.Path(self.local_project_path())
+            for pattern in files:
+                for path in project_path.glob(pattern):
+                    if not path.is_file():
+                        continue
+
+                    if not path.parent == project_path:
+                        # If the dependency belongs in a separate folder, make it
+                        self._config.server.execute(
+                            "mkdir -p "
+                            + self.remote_experiment_path(
+                                path.parent.relative_to(project_path).as_posix()
+                            )
+                        )
+
+                    ftp.put(
+                        str(path),
+                        self.remote_experiment_path(
+                            path.relative_to(project_path).as_posix()
+                        ),
+                    )
 
     def _setup_all(self, num_workers, time, cpus_per_worker=1):
         """
@@ -511,7 +525,7 @@ class SlurmInstance(ExperimentInstance):
         self._exp.prepare_server(self)
 
         # Generate a command to complete submission
-        return 'sbatch --output="{0}" --workdir="{1}" --array=0-{2} {3} {4}'.format(
+        return 'sbatch --output="{0}" -D "{1}" --array=0-{2} {3} {4}'.format(
             self.remote_experiment_path("slurm_%a.worker"),
             self.remote_experiment_path(""),
             str(num_workers - 1),
